=========
Reference
=========

References to individual classes and their functions, methods, and properties.

.. currentmodule:: sosia

.. _class_original:

sosia.Original
==============

.. autoclass:: Original
   :inherited-members:
   :members:


sosia.get_field_source_information
==================================

.. autofunction:: get_field_source_information


sosia.make_database
===================

.. autofunction:: make_database
